@@ -2,9 +2,10 @@
 sweep.py contains the classes for sweeping
 """
 
+from itertools import product
+
 from SQcircuit.circuit import *
 from SQcircuit.storage import *
-from itertools import product
 
 
 class Sweep(SQdata):
@@ -64,7 +65,8 @@ class Sweep(SQdata):
         """
         return tuple(map(range, map(len, grid)))
 
-    def sweepFlux(self, loops: list, grid: list, toFile: str = None, plotF: bool = False):
+    def sweepFlux(self, loops: list, grid: list,
+                  toFile: str = None, plotF: bool = False):
 
         self.type = "sweepFlux"
         self.params = loops
@@ -81,13 +83,13 @@ class Sweep(SQdata):
 
             # set flux for each loop
             for i, ind in enumerate(indices):
-                loops[i].setFlux(grid[i][ind])
+                loops[i].set_flux(grid[i][ind])
 
             evec, _ = self.cr.diag(self.numEig)
             self.efreq[:, indices] = evec.reshape(self.efreq[:, indices].shape)
             if "loss" in self.properties:
-                for decType in self.dec.keys():
-                    self.dec[decType][indices] = self.cr.decRate(decType=decType, states=(1, 0))
+                for dec_type in self.dec.keys():
+                    self.dec[dec_type][indices] = self.cr.dec_rate(dec_type=dec_type, states=(1, 0))
 
         print("Sweeping process is finished!")
 
@@ -100,7 +102,8 @@ class Sweep(SQdata):
         else:
             return self.efreq, self.dec
 
-    def sweepCharge(self, modes: list, grid: list, toFile: str = None, plotF: bool = False):
+    def sweepCharge(self, modes: list, grid: list,
+                    toFile: str = None, plotF: bool = False):
 
         self.type = "sweepCharge"
         self.params = modes
@@ -117,13 +120,13 @@ class Sweep(SQdata):
 
             # set flux for each loop
             for i, ind in enumerate(indices):
-                self.cr.chargeOffset(mode=modes[i], ng=grid[i][ind])
+                self.cr.set_charge_offset(mode=modes[i], ng=grid[i][ind])
 
             evec, _ = self.cr.diag(self.numEig)
             self.efreq[:, indices] = evec.reshape(self.efreq[:, indices].shape)
             if "loss" in self.properties:
-                for decType in self.dec.keys():
-                    self.dec[decType][indices] = self.cr.decRate(decType=decType, states=(1, 0))
+                for dec_type in self.dec.keys():
+                    self.dec[dec_type][indices] = self.cr.dec_rate(dec_type=dec_type, states=(1, 0))
 
         print("Sweeping process is finished!")
 
